package com.xlht.xlhtproject.service.impl;

import java.util.List;

import com.xlht.xlhtproject.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.xlht.xlhtproject.mapper.ZAssayFaultMapper;
import com.xlht.xlhtproject.domain.ZAssayFault;
import com.xlht.xlhtproject.service.IZAssayFaultService;

/**
 * 设备故障信息Service业务层处理
 * 
 * @author slibra
 * @date 2024-09-19
 */
@Service
public class ZAssayFaultServiceImpl implements IZAssayFaultService 
{
    @Autowired
    private ZAssayFaultMapper zAssayFaultMapper;

    /**
     * 查询设备故障信息
     * 
     * @param faultId 设备故障信息主键
     * @return 设备故障信息
     */
    @Override
    public ZAssayFault selectZAssayFaultByFaultId(Long faultId)
    {
        return zAssayFaultMapper.selectZAssayFaultByFaultId(faultId);
    }

    /**
     * 查询设备故障信息列表
     * 
     * @param zAssayFault 设备故障信息
     * @return 设备故障信息
     */
    @Override
    public List<ZAssayFault> selectZAssayFaultList(ZAssayFault zAssayFault)
    {
        return zAssayFaultMapper.selectZAssayFaultList(zAssayFault);
    }

    /**
     * 新增设备故障信息
     * 
     * @param zAssayFault 设备故障信息
     * @return 结果
     */
    @Override
    public int insertZAssayFault(ZAssayFault zAssayFault)
    {
        zAssayFault.setCreateTime(DateUtils.getNowDate());
        return zAssayFaultMapper.insertZAssayFault(zAssayFault);
    }

    /**
     * 修改设备故障信息
     * 
     * @param zAssayFault 设备故障信息
     * @return 结果
     */
    @Override
    public int updateZAssayFault(ZAssayFault zAssayFault)
    {
        zAssayFault.setUpdateTime(DateUtils.getNowDate());
        return zAssayFaultMapper.updateZAssayFault(zAssayFault);
    }

    /**
     * 批量删除设备故障信息
     * 
     * @param faultIds 需要删除的设备故障信息主键
     * @return 结果
     */
    @Override
    public int deleteZAssayFaultByFaultIds(Long[] faultIds)
    {
        return zAssayFaultMapper.deleteZAssayFaultByFaultIds(faultIds);
    }

    /**
     * 删除设备故障信息信息
     * 
     * @param faultId 设备故障信息主键
     * @return 结果
     */
    @Override
    public int deleteZAssayFaultByFaultId(Long faultId)
    {
        return zAssayFaultMapper.deleteZAssayFaultByFaultId(faultId);
    }
}
